errc

Function errc 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn errc( eval: c_int, code: c_int, fmt: *const c_char, ... ) -> !
Print a user message then an error message for code before exiting with eval as a return.

The message format is progname: fmt: strerror(code)

Return

Exits with eval as an error code.